@@ -31,10 +31,10 @@ pub fn ffi_service(attr: AttributeArgs, input: TokenStream) -> TokenStream {
     let service_type = &item.self_ty;
     let mut function_descriptors = Vec::new();
 
-    for x in &item.items {
-        if let ImplItem::Method(x) = x {
-            if let Some(xx) = generate_service_method(&attributes, &item, x) {
-                function_descriptors.push(xx);
+    for impl_item in &item.items {
+        if let ImplItem::Method(method) = impl_item {
+            if let Some(descriptor) = generate_service_method(&attributes, &item, method) {
+                function_descriptors.push(descriptor);
             }
         }
     }
@@ -46,11 +46,11 @@ pub fn ffi_service(attr: AttributeArgs, input: TokenStream) -> TokenStream {
         .filter(|x| matches!(x.method_type, MethodType::Method(_)))
         .map(|x| x.ident.clone())
         .collect::<Vec<_>>();
-    let ffi_ctor_ident = &function_descriptors
+    let ffi_ctors = function_descriptors
         .iter()
-        .find(|x| matches!(x.method_type, MethodType::Constructor(_)))
-        .expect("Must have constructor.")
-        .ident;
+        .filter(|x| matches!(x.method_type, MethodType::Constructor(_)))
+        .map(|x| x.ident.clone())
+        .collect::<Vec<_>>();
 
     let ffi_dtor_quote = &ffi_dtor.ffi_function_tokens;
     let ffi_dtor_ident = &ffi_dtor.ident;
@@ -74,6 +74,7 @@ pub fn ffi_service(attr: AttributeArgs, input: TokenStream) -> TokenStream {
                 use ::interoptopus::lang::rust::FunctionInfo;
 
                 let mut methods = Vec::new();
+                let mut ctors = Vec::new();
 
                 #(
                     {
@@ -82,10 +83,13 @@ pub fn ffi_service(attr: AttributeArgs, input: TokenStream) -> TokenStream {
                     }
                 )*
 
-                let ctor = {
-                    use #ffi_ctor_ident as x;
-                    x::function_info()
-                };
+
+                #(
+                    {
+                        use #ffi_ctors as x;
+                        ctors.push(x::function_info());
+                    }
+                )*
 
                 let dtor = {
                     use #ffi_dtor_ident as x;
@@ -93,7 +97,7 @@ pub fn ffi_service(attr: AttributeArgs, input: TokenStream) -> TokenStream {
                 };
 
                 let service = ::interoptopus::patterns::service::Service::new(
-                    ctor, dtor, methods,
+                    ctors, dtor, methods,
                 );
 
                 service.assert_valid();
@@ -109,74 +113,3 @@ pub fn ffi_service(attr: AttributeArgs, input: TokenStream) -> TokenStream {
 
     rval
 }
-
-// pub(crate) fn simple_service_pattern() -> interoptopus::patterns::service::Service {
-//     use interoptopus::lang::rust::CTypeInfo;
-//     use interoptopus::lang::rust::FunctionInfo;
-//
-//     let mut methods = Vec::new();
-//
-//     {
-//         {
-//             use simple_service_result
-//             as x;
-//             methods.push(x::function_info());
-//         }
-//         {
-//             use simple_service_value    as x;
-//             methods.push(x::function_info());
-//         }
-//         {
-//             use simple_service_mut_self    as x;
-//             methods.push(x::function_info());
-//         }
-//         {
-//             use simple_service_mut_self_void    as x;
-//             methods.push(x::function_info());
-//         }
-//         {
-//             use simple_service_mut_self_ref    as x;
-//             methods.push(x::function_info());
-//         }
-//         {
-//             use simple_service_mut_self_ref_slice    as x;
-//             methods.push(x::function_info());
-//         }
-//         {
-//             use simple_service_mut_self_ref_slice_limited    as x;
-//             methods.push(x::function_info());
-//         }
-//         {
-//             use simple_service_mut_self_ffi_error    as x;
-//             methods.push(x::function_info());
-//         }
-//         {
-//             use simple_service_void
-//             as x;
-//             methods.push(x::function_info());
-//         }
-//         {
-//             use simple_service_extra_method
-//
-//             as x;
-//             methods.push(x::function_info());
-//         }
-//     }
-//
-//     let ctor = {
-//         use simple_service_create    as x;
-//         x::function_info()
-//     };
-//
-//     let dtor = {
-//         use simple_service_destroy    as x;
-//         x::function_info()
-//     };
-//
-//     let rval = interoptopus::patterns::service::Service::new(
-//         ctor, dtor, methods,
-//     );
-//
-//     rval.assert_valid();
-//     rval
-// }
